==> carbon-components-react-0.9.0.tgz: package/es/components/StructuredList/index.js <==
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import React from 'react';
import { StructuredListWrapper as StructuredListWrapperNext, StructuredListHead as StructuredListHeadNext, StructuredListInput as StructuredListInputNext, StructuredListBody as StructuredListBodyNext, StructuredListRow as StructuredListRowNext, StructuredListCell as StructuredListCellNext } from './next/StructuredList';
import { StructuredListWrapper as StructuredListWrapperClassic, StructuredListHead as StructuredListHeadClassic, StructuredListInput as StructuredListInputClassic, StructuredListBody as StructuredListBodyClassic, StructuredListRow as StructuredListRowClassic, StructuredListCell as StructuredListCellClassic } from './StructuredList';
import { useFeatureFlag } from '../FeatureFlags';
export function StructuredListWrapper(props) {
  var enabled = useFeatureFlag('enable-2021-release');

  if (enabled) {
    return /*#__PURE__*/React.createElement(StructuredListWrapperNext, props);
  }

  return /*#__PURE__*/React.createElement(StructuredListWrapperClassic, props);
}
export function StructuredListHead(props) {
  var enabled = useFeatureFlag('enable-2021-release');

  if (enabled) {
    return /*#__PURE__*/React.createElement(StructuredListHeadNext, props);
  }

  return /*#__PURE__*/React.createElement(StructuredListHeadClassic, props);
}
export function StructuredListInput(props) {
  var enabled = useFeatureFlag('enable-2021-release');

  if (enabled) {
    return /*#__PURE__*/React.createElement(StructuredListInputNext, props);
  }

  return /*#__PURE__*/React.createElement(StructuredListInputClassic, props);
}
export function StructuredListBody(props) {
  var enabled = useFeatureFlag('enable-2021-release');

  if (enabled) {
    return /*#__PURE__*/React.createElement(StructuredListBodyNext, props);
  }

  return /*#__PURE__*/React.createElement(StructuredListBodyClassic, props);
}
export function StructuredListRow(props) {
  var enabled = useFeatureFlag('enable-2021-release');

  if (enabled) {
    return /*#__PURE__*/React.createElement(StructuredListRowNext, props);
  }

  return /*#__PURE__*/React.createElement(StructuredListRowClassic, props);
}
export function StructuredListCell(props) {
  var enabled = useFeatureFlag('enable-2021-release');

  if (enabled) {
    return /*#__PURE__*/React.createElement(StructuredListCellNext, props);
  }

  return /*#__PURE__*/React.createElement(StructuredListCellClassic, props);
}
export { default as StructuredListSkeleton } from './StructuredList.Skeleton';

==> carbon-components-react-2.0.4.tgz: package/es/components/StructuredList/index.js <==
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import React from 'react';
import { StructuredListWrapper as StructuredListWrapperNext, StructuredListHead as StructuredListHeadNext, StructuredListInput as StructuredListInputNext, StructuredListBody as StructuredListBodyNext, StructuredListRow as StructuredListRowNext, StructuredListCell as StructuredListCellNext } from './next/StructuredList';
import { StructuredListWrapper as StructuredListWrapperClassic, StructuredListHead as StructuredListHeadClassic, StructuredListInput as StructuredListInputClassic, StructuredListBody as StructuredListBodyClassic, StructuredListRow as StructuredListRowClassic, StructuredListCell as StructuredListCellClassic } from './StructuredList';
import { useFeatureFlag } from '../FeatureFlags';
export function StructuredListWrapper(props) {
  var enabled = useFeatureFlag('enable-v11-release');

  if (enabled) {
    return /*#__PURE__*/React.createElement(StructuredListWrapperNext, props);
  }

  return /*#__PURE__*/React.createElement(StructuredListWrapperClassic, props);
}
export function StructuredListHead(props) {
  var enabled = useFeatureFlag('enable-v11-release');

  if (enabled) {
    return /*#__PURE__*/React.createElement(StructuredListHeadNext, props);
  }

  return /*#__PURE__*/React.createElement(StructuredListHeadClassic, props);
}
export function StructuredListInput(props) {
  var enabled = useFeatureFlag('enable-v11-release');

  if (enabled) {
    return /*#__PURE__*/React.createElement(StructuredListInputNext, props);
  }

  return /*#__PURE__*/React.createElement(StructuredListInputClassic, props);
}
export function StructuredListBody(props) {
  var enabled = useFeatureFlag('enable-v11-release');

  if (enabled) {
    return /*#__PURE__*/React.createElement(StructuredListBodyNext, props);
  }

  return /*#__PURE__*/React.createElement(StructuredListBodyClassic, props);
}
export function StructuredListRow(props) {
  var enabled = useFeatureFlag('enable-v11-release');

  if (enabled) {
    return /*#__PURE__*/React.createElement(StructuredListRowNext, props);
  }

  return /*#__PURE__*/React.createElement(StructuredListRowClassic, props);
}
export function StructuredListCell(props) {
  var enabled = useFeatureFlag('enable-v11-release');

  if (enabled) {
    return /*#__PURE__*/React.createElement(StructuredListCellNext, props);
  }

  return /*#__PURE__*/React.createElement(StructuredListCellClassic, props);
}
export { default as StructuredListSkeleton } from './StructuredList.Skeleton';
